Ep17 Le 1er Avril = La Fete de l'Esprit Critique

Hygiène Mentale

Ep17 Le 1er Avril = La Fete de l'Esprit Critique

Faisons comme si chaque jour était un 1er avril.
● Le 1er avril c'est pas seulement le jour de la blague potache, et du canular sournois.
● Le 1er avril c'est aussi, et surtout, la fête de l'Esprit Critique. C'est le seul jour de l'année où tout le monde est vigilent, aux aguets.
● Le 1er avril personne n'a envie de se faire avoir, de passer pour un âne a partager une intox. Du coup tout le monde fait bien attention a verifier les infos avant de les afficher sur son mur.
● Le 1er avril c'est mon jour de l'année préféré.
C'est le seul jour où le monde ne marche pas sur la tête, où les gens se comportent normalement.
C'est comme un jour de vacance pour les sceptiques, et les équipes de hoaxbuster.
________________________
SOURCES
Les saucisses au festival Vegan :
http://www.lenouvelliste.ch/articles/monde/allemagne-la-commune-d-hessenschau-impose-la-vente-de-saucisse-lors-d-un-festival-vegan-641007
Le champs de force a UltraSon pour isoler votre maison :
http://www.demotivateur.fr/article-buzz/un-enorme-champ-de-force-permettant-de-proteger-une-maison-c-est-possible-et-en-fait-cela-existe-meme-deja-quand-la-realite-rattrape-la-science-fiction--3551
Le site officiel du produit a disparu, mais une archive est disponible ici :
https://web.archive.org/web/20151116152707/http://www.ultradome360.com/
_______________________________
Musique d'intro : Koenjiyakkei
Musique de fond Kevin McLeaod
Le facebook : http://facebook.com/HygieneMentale
Le twitter : https://twitter.com/HygieneMentale
Le Diaspora* : https://framasphere.org/people/43360ee086750134e9c62a0000053625
Le site : http://laelith.fr/Zet
L'association : http://zetetique.fr
Le Tipee : https://www.tipeee.com/hygiene-mentale

31/03/2017